#!perl

BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    print qq{1..0 # SKIP these tests are for testing by the author\n};
    exit
  }
}


use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::Perl::Critic::Subset 3.001.006

use Test::Perl::Critic (-profile => "") x!! -e "";

my $filenames = ['lib/App/SerializeUtils.pm','script/check-json','script/check-phpser','script/check-yaml','script/json2json','script/json2perl','script/json2perlcolor','script/json2phpser','script/json2sereal','script/json2sexp','script/json2storable','script/json2yaml','script/perl2json','script/perl2perl','script/perl2perlcolor','script/perl2phpser','script/perl2sereal','script/perl2sexp','script/perl2storable','script/perl2yaml','script/phpser2json','script/phpser2perl','script/phpser2perlcolor','script/phpser2sereal','script/phpser2sexp','script/phpser2storable','script/phpser2yaml','script/pp-json','script/pp-perl','script/pp-yaml','script/sereal2json','script/sereal2perl','script/sereal2perlcolor','script/sereal2phpser','script/sereal2sexp','script/sereal2storable','script/sereal2yaml','script/serializeutils-convert','script/sexp2json','script/sexp2perl','script/sexp2perlcolor','script/sexp2phpser','script/sexp2sereal','script/sexp2storable','script/sexp2yaml','script/storable2json','script/storable2perl','script/storable2perlcolor','script/storable2phpser','script/storable2sereal','script/storable2sexp','script/storable2yaml','script/yaml2json','script/yaml2perl','script/yaml2perlcolor','script/yaml2phpser','script/yaml2sereal','script/yaml2sexp','script/yaml2storabls','script/yaml2yaml'];
unless ($filenames && @$filenames) {
    $filenames = -d "blib" ? ["blib"] : ["lib"];
}

all_critic_ok(@$filenames);
